@@ -21,7 +21,10 @@ from pyinspect._colors import (
 
 from rich import pretty
 
-pretty.install()
+pretty.install(
+    overflow="ellipse",
+    max_length=33,
+)
 
 try:
     from github import Github
@@ -35,7 +38,7 @@ __maintainer__ = "Federico Claudi"
 __email__ = "federicoclaudi@protonmail.com"
 __status__ = "dev"
 __website__ = "https://github.com/FedeClaudi/pyinspect"
-__version__ = "0.0.7"
+__version__ = "0.1.0"
 
 
 def whats_pi():
